Struct OrderBookResponse
pub struct OrderBookResponse {Show 28 fields
pub timestamp: i64,
pub state: String,
pub stats: OrderBookStats,
pub greeks: Option<OrderBookGreeks>,
pub change_id: i64,
pub index_price: f64,
pub instrument_name: String,
pub option_token_address: Option<WalletAddress>,
pub bids: Vec<[f64; 2]>,
pub asks: Vec<[f64; 2]>,
pub last_price: Option<f64>,
pub settlement_price: f64,
pub min_price: f64,
pub max_price: f64,
pub open_interest: f64,
pub mark_price: f64,
pub theoretical_price: Option<f64>,
pub best_bid_price: f64,
pub best_ask_price: f64,
pub mark_iv: Option<f64>,
pub ask_iv: Option<f64>,
pub bid_iv: Option<f64>,
pub underlying_price: f64,
pub underlying_index: String,
pub interest_rate: f64,
pub estimated_delivery_price: f64,
pub best_ask_amount: f64,
pub best_bid_amount: f64,
}Expand description
Orderbook response.
Fields
timestamp: i64Timestamp
state: StringMarket state
stats: OrderBookStatsOrder book statistics
greeks: Option<OrderBookGreeks>Option Greeks
change_id: i64Change ID for incremental updates
index_price: f64Index price
instrument_name: StringInstrument name
option_token_address: Option<WalletAddress>Option token contract address
bids: Vec<[f64; 2]>Bid orders [price, size], where size is in human-readable contracts.
asks: Vec<[f64; 2]>Ask orders [price, size], where size is in human-readable contracts.
last_price: Option<f64>Last trade price
settlement_price: f64Settlement price
min_price: f64Minimum price
max_price: f64Maximum price
open_interest: f64Open interest
mark_price: f64Mark price
theoretical_price: Option<f64>Theoretical option price derived from the vol oracle, when available.
best_bid_price: f64Best bid price
best_ask_price: f64Best ask price
mark_iv: Option<f64>Theoretical implied volatility used for mark price and greeks.
ask_iv: Option<f64>Quote-derived ask-side implied volatility
bid_iv: Option<f64>Quote-derived bid-side implied volatility
underlying_price: f64Underlying price
underlying_index: StringUnderlying index name
interest_rate: f64Interest rate
estimated_delivery_price: f64Estimated delivery price
best_ask_amount: f64Best ask amount in human-readable contracts.
best_bid_amount: f64Best bid amount in human-readable contracts.